#
# spec file for package python-argparse
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           python-argparse
Version:        1.3.0
Release:        5.2
Url:            http://code.google.com/p/argparse/
Summary:        Python command-line parsing library
License:        Python-2.0
Group:          Development/Languages/Python
Source:         https://pypi.python.org/packages/source/a/argparse/argparse-%{version}.tar.gz
Source1:        argparse-1.1.pdf
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  python-devel
BuildRequires:  python-setuptools
%if 0%{?suse_version}
%py_requires
%if 0%{?suse_version} > 1110
BuildArch:      noarch
%endif
%endif
Provides:       python-argparse-doc = %{version}
Obsoletes:      python-argparse-doc < %{version}
# For some distros, the "python" package provides python-argparse.
# This allows packages to explicitly define that it needs this
# backported version rather than the included version.
Provides:       python-argparse-backport = %{version}
Obsoletes:      python-argparse-backport < %{version}
%{!?python_sitelib: %global python_sitelib %(%{__python} -c "from distutils.sysconfig import get_python_lib; print get_python_lib()")}

%description
The argparse module provides an easy, declarative interface for
creating command line tools, which knows how to:

* parse the arguments and flags from sys.argv
* convert arg strings into objects for your program
* format and print informative help messages
* and much more... 

The argparse module improves on the standard library optparse module
in a number of ways including:

* handling positional arguments
* supporting sub-commands
* allowing alternative option prefixes like + and /
* handling zero-or-more and one-or-more style arguments
* producing more informative usage messages
* providing a much simpler interface for custom types and actions 

%prep
%setup -n argparse-%{version}
mkdir html
pushd doc
    mv * ../html/
    mv ../html .
popd
sed -i "s/\r//" NEWS.txt # Avoid warning wrong-file-end-of-line-encoding
cp %{SOURCE1} doc/

%build
python setup.py build

%install
python setup.py install --prefix=%{_prefix} --root=%{buildroot}

%files 
%defattr(-,root,root,-)
%doc NEWS.txt README.txt doc/*
%python_sitelib/*

%changelog
* Fri Aug 21 2015 toddrme2178@gmail.com
- Add python-argparse-backport provides
  For some distros, the "python" package provides python-argparse.
  This allows packages to explicitly define that it needs this
  backported version rather than the included version.
* Sun Apr 19 2015 benoit.monin@gmx.fr
- update to version 1.3.0:
  * added aliases support (thanks to Roland Kammerer!) + tests
    for it
  * use tox for testing python >= 2.6
  * tests successfully on 3.4 also (without random hash seed)
  * added argparse.__external_lib__ = True so one can test one is
    really using / testing the external library (and not the
    builtin one in stdlib of recent Pythons)
- additional change from 1.2.2:
  * added universal wheel support, built, signed and uploaded with:
    python setup.py sdist bdist_wheel upload
  - -identity="Thomas Waldmann" --sign
  * host the files on pypi
- set the source URL to pypi
- change obsolete of python-argparse-doc back to '<' after
  version update
* Thu Oct 24 2013 speilicke@suse.com
- Require python-setuptools instead of distribute (upstreams merged)
* Sun Apr 14 2013 p.drouand@gmail.com
- Initial python3 support
* Thu Sep 22 2011 saschpe@suse.de
- Corrected license to Python-2.0
* Thu Sep 22 2011 saschpe@suse.de
- Set license to Apache-2.0 (SPDX style)
- Merge doc package back into base package
- Remove %%clean section and authors from description
- Require python-distribute instead of python-setuptools
* Fri Apr  1 2011 alexandre@exatati.com.br
- Update to 1.2.1:
  - fixed Issue #82: argparse 1.2 incompatible with Python 3.1
  - hacked the tests so they don't have the minor failures that were caused
    by the compatibility stuff for python 2.3 and 3.1
* Mon Mar 28 2011 alexandre@exatati.com.br
- Update to 1.2:
  - fixed Issue #79: re-licensed argparse package under same
    license as py 2.7 stdlib argparse code
  - fixed Issue #80: argparse 1.2 is now same archive on pypi / on
    google code
- Hard-coded PDF version as it is not following release number
  (at least for now).
* Wed Dec 15 2010 saschpe@suse.de
- Re-add documentation subpackage
  * Got lost in previous commit
  * Also add NEWS.txt and README.txt
* Sat Dec 11 2010 saschpe@gmx.de
- Re-generated spec file with py2pack, now builds for Fedora and
  Mandriva.
* Tue Sep  7 2010 alexandre@exatati.com.br
- Bzip2 source file;
- Spec file cleaned with spec-cleaner.
* Sun May 30 2010 toms@suse.de
  SPEC file changes:
- Create subpackage for documentation
- Added %%changelog
- Used macro "modname"
- Added additionally PDF for documentation subpackage
* Mon Mar  1 2010 alexandre@exatati.com.br
- Update to 1.1.
* Thu Dec 10 2009 alexandre@exatati.com.br
- Initial package (1.0.1) for openSUSE.
